package com.yiqi.admin.controller.order;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.order.domain.OrderClothCouponRelation;
import com.yiqi.order.service.IOrderClothCouponRelationService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 洗衣订单优惠券使用情况Controller
 *
 * @author xiaohei
 * @date 2023-11-07
 */
@Api(tags = "管理后台 - 洗衣订单优惠券使用情况")
@RestController
@RequestMapping(UrlConstants.managerApi + "/order/orderClothCouponRelation")
public class OrderClothCouponRelationController extends BaseController {
    @Autowired
    private IOrderClothCouponRelationService orderClothCouponRelationService;

    /**
     * 查询洗衣订单优惠券使用情况列表
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothCouponRelation:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询洗衣订单优惠券使用情况列表")
    public TableDataInfo list(OrderClothCouponRelation orderClothCouponRelation) {
        startPage();
        List<OrderClothCouponRelation> list = orderClothCouponRelationService.selectOrderClothCouponRelationList(orderClothCouponRelation);
        return getDataTable(list);
    }

    /**
     * 导出洗衣订单优惠券使用情况列表
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothCouponRelation:export')")
    @Log(title = "洗衣订单优惠券使用情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出洗衣订单优惠券使用情况列表")
    public void export(HttpServletResponse response, OrderClothCouponRelation orderClothCouponRelation) {
        List<OrderClothCouponRelation> list = orderClothCouponRelationService.selectOrderClothCouponRelationList(orderClothCouponRelation);
        ExcelUtil<OrderClothCouponRelation> util = new ExcelUtil<OrderClothCouponRelation>(OrderClothCouponRelation. class);
        util.exportExcel(response, list, "洗衣订单优惠券使用情况数据");
    }

    /**
     * 获取洗衣订单优惠券使用情况详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothCouponRelation:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取洗衣订单优惠券使用情况详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderClothCouponRelationService.selectOrderClothCouponRelationById(id));
    }

    /**
     * 新增洗衣订单优惠券使用情况
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothCouponRelation:add')")
    @Log(title = "洗衣订单优惠券使用情况", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增洗衣订单优惠券使用情况")
    public AjaxResult add(@RequestBody OrderClothCouponRelation orderClothCouponRelation) {
        orderClothCouponRelation.setCreateById(getUserId());
        orderClothCouponRelation.setCreateBy(getUsername());
        return toAjax(orderClothCouponRelationService.insertOrderClothCouponRelation(orderClothCouponRelation));
    }

    /**
     * 修改洗衣订单优惠券使用情况
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothCouponRelation:edit')")
    @Log(title = "洗衣订单优惠券使用情况", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改洗衣订单优惠券使用情况")
    public AjaxResult edit(@RequestBody OrderClothCouponRelation orderClothCouponRelation) {
        orderClothCouponRelation.setUpdateById(getUserId());
        orderClothCouponRelation.setUpdateBy(getUsername());
        return toAjax(orderClothCouponRelationService.updateOrderClothCouponRelation(orderClothCouponRelation));
    }

    /**
     * 删除洗衣订单优惠券使用情况
     */
    @PreAuthorize("@ss.hasPermi('order:orderClothCouponRelation:remove')")
    @Log(title = "洗衣订单优惠券使用情况", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除洗衣订单优惠券使用情况")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderClothCouponRelationService.deleteOrderClothCouponRelationByIds(ids));
    }

}
